aws-greengrass-group-setup
--------------------------

Greengrass ``gg_group_setup`` is an example of file-driven approach to the creation
of an entire AWS Greengrass group.

**Documentation**: https://github.com/awslabs/aws-greengrass-group-setup